changeset 44399:a399428859ff

(Fplay_sound_internal): Renamed from Fplay_sound. Doc fix to reflect it.
author Pavel Janík <Pavel@Janik.cz>
date Fri, 05 Apr 2002 05:49:20 +0000
parents b31ff653a546
children dfe85fad7802
files src/sound.c
diffstat 1 files changed, 5 insertions(+), 19 deletions(-) [+]
line wrap: on
line diff
--- a/src/sound.c	Thu Apr 04 21:19:32 2002 +0000
+++ b/src/sound.c	Fri Apr 05 05:49:20 2002 +0000
@@ -220,7 +220,7 @@
 Lisp_Object Qsound;
 Lisp_Object Qplay_sound_functions;
 
 /* These are set during `play-sound' so that sound_cleanup has
    access to them.  */
 
 struct sound_device *current_sound_device;
@@ -371,7 +371,7 @@
 }
 
 
 /* Function installed by play-sound with record_unwind_protect.  */
 
 static Lisp_Object
 sound_cleanup (arg)
@@ -389,24 +389,10 @@
 }
 
 
-DEFUN ("play-sound", Fplay_sound, Splay_sound, 1, 1, 0,
+DEFUN ("play-sound-internal", Fplay_sound_internal, Splay_sound_internal, 1, 1, 0,
        doc: /* Play sound SOUND.
-SOUND is a list of the form `(sound KEYWORD VALUE...)'.
-The following keywords are recognized:
-
-  :file FILE - read sound data from FILE.  If FILE isn't an
-absolute file name, it is searched in `data-directory'.
 
-  :data DATA - read sound data from string DATA.
-
-Exactly one of :file or :data must be present.
-
-  :volume VOL - set volume to VOL.  VOL must an integer in the
-range 0..100 or a float in the range 0..1.0.  If not specified,
-don't change the volume setting of the sound device.
-
-  :device DEVICE - play sound on DEVICE.  If not specified,
-a system-dependent default device name is used.  */)
+Internal use only, use `play-sound' instead.  */)
      (sound)
      Lisp_Object sound;
 {
@@ -954,7 +940,7 @@
   Qplay_sound_functions = intern ("play-sound-functions");
   staticpro (&Qplay_sound_functions);
 
-  defsubr (&Splay_sound);
+  defsubr (&Splay_sound_internal);
 }
@@ -220,7 +220,7 @@
 Lisp_Object Qplay_sound_functions;
 
-/* These are set during `play-sound' so that sound_cleanup has
+/* These are set during `play-sound-internal' so that sound_cleanup has
    access to them.  */
 
@@ -371,7 +371,7 @@
 
 
-/* Function installed by play-sound with record_unwind_protect.  */
+/* Function installed by play-sound-internal with record_unwind_protect.  */
 
 static Lisp_Object